.. _getting_started:

These pages give you everything you need to start editing with MoviePy. Then the best way to learn is to have a look at the provided :ref:`examples` or the different ressources presented in the :ref:`gallery`.


Getting started with MoviePy
------------------------------


.. toctree::
   :maxdepth: 1
   
   quick_presentation
   clips
   compositing
   effects
   advanced_tools
   efficient_moviepy